@@ -1915,6 +1915,15 @@ static const char *milter8_conn_event(MILTER *m,
 #define STR_EQ(x,y)	(strcmp((x), (y)) == 0)
 #define STR_NE(x,y)	(strcmp((x), (y)) != 0)
 
+    /*
+     * XXX Sendmail 8 libmilter closes the MTA-to-filter socket when it finds
+     * out that the SMTP client has disconnected. Because of this, Postfix
+     * has to open a new MTA-to-filter socket for each SMTP client.
+     */
+#ifdef LIBMILTER_AUTO_DISCONNECT
+    milter8_connect(milter);
+#endif
+
     /*
      * Report the event.
      */
@@ -2824,10 +2833,6 @@ static MILTER8 *milter8_alloc(const char *name, int conn_timeout,
 
     /*
      * Fill in the structure. Note: all strings must be copied.
-     * 
-     * XXX Sendmail 8 libmilter closes the MTA-to-filter socket when it finds
-     * out that the SMTP client has disconnected. Because of this, Postfix
-     * has to open a new MTA-to-filter socket for each SMTP client.
      */
     milter = (MILTER8 *) mymalloc(sizeof(*milter));
     milter->m.name = mystrdup(name);
@@ -2835,11 +2840,6 @@ static MILTER8 *milter8_alloc(const char *name, int conn_timeout,
     milter->m.next = 0;
     milter->m.parent = parent;
     milter->m.macros = 0;
-#ifdef LIBMILTER_AUTO_DISCONNECT
-    milter->m.connect_on_demand = (void (*) (struct MILTER *)) milter8_connect;
-#else
-    milter->m.connect_on_demand = 0;
-#endif
     milter->m.conn_event = milter8_conn_event;
     milter->m.helo_event = milter8_helo_event;
     milter->m.mail_event = milter8_mail_event;
